==> openshift-model-operator-6.3.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerHTTPHeadersFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressControllerHTTPHeadersFluent<A extends IngressControllerHTTPHeadersFluent<A>> extends Fluent<A>{
  public String getForwardedHeaderPolicy();
  public A withForwardedHeaderPolicy(String forwardedHeaderPolicy);
  public Boolean hasForwardedHeaderPolicy();
  public A addToHeaderNameCaseAdjustments(Integer index,String item);
  public A setToHeaderNameCaseAdjustments(Integer index,String item);
  public A addToHeaderNameCaseAdjustments(java.lang.String... items);
  public A addAllToHeaderNameCaseAdjustments(Collection<String> items);
  public A removeFromHeaderNameCaseAdjustments(java.lang.String... items);
  public A removeAllFromHeaderNameCaseAdjustments(Collection<String> items);
  public List<String> getHeaderNameCaseAdjustments();
  public String getHeaderNameCaseAdjustment(Integer index);
  public String getFirstHeaderNameCaseAdjustment();
  public String getLastHeaderNameCaseAdjustment();
  public String getMatchingHeaderNameCaseAdjustment(Predicate<String> predicate);
  public Boolean hasMatchingHeaderNameCaseAdjustment(Predicate<String> predicate);
  public A withHeaderNameCaseAdjustments(List<String> headerNameCaseAdjustments);
  public A withHeaderNameCaseAdjustments(java.lang.String... headerNameCaseAdjustments);
  public Boolean hasHeaderNameCaseAdjustments();
  
  /**
   * This method has been deprecated, please use method buildUniqueId instead.
   * @return The buildable object.
   */
  @Deprecated
  public IngressControllerHTTPUniqueIdHeaderPolicy getUniqueId();
  public IngressControllerHTTPUniqueIdHeaderPolicy buildUniqueId();
  public A withUniqueId(IngressControllerHTTPUniqueIdHeaderPolicy uniqueId);
  public Boolean hasUniqueId();
  public A withNewUniqueId(String format,String name);
  public IngressControllerHTTPHeadersFluent.UniqueIdNested<A> withNewUniqueId();
  public IngressControllerHTTPHeadersFluent.UniqueIdNested<A> withNewUniqueIdLike(IngressControllerHTTPUniqueIdHeaderPolicy item);
  public IngressControllerHTTPHeadersFluent.UniqueIdNested<A> editUniqueId();
  public IngressControllerHTTPHeadersFluent.UniqueIdNested<A> editOrNewUniqueId();
  public IngressControllerHTTPHeadersFluent.UniqueIdNested<A> editOrNewUniqueIdLike(IngressControllerHTTPUniqueIdHeaderPolicy item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface UniqueIdNested<N> extends Nested<N>,IngressControllerHTTPUniqueIdHeaderPolicyFluent<IngressControllerHTTPHeadersFluent.UniqueIdNested<N>>{
    public N and();
    public N endUniqueId();
    
  }
  
}

==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerHTTPHeadersFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressControllerHTTPHeadersFluent<A extends IngressControllerHTTPHeadersFluent<A>> extends Fluent<A>{
  public String getForwardedHeaderPolicy();
  public A withForwardedHeaderPolicy(String forwardedHeaderPolicy);
  public Boolean hasForwardedHeaderPolicy();
  public A addToHeaderNameCaseAdjustments(int index,String item);
  public A setToHeaderNameCaseAdjustments(int index,String item);
  public A addToHeaderNameCaseAdjustments(java.lang.String... items);
  public A addAllToHeaderNameCaseAdjustments(Collection<String> items);
  public A removeFromHeaderNameCaseAdjustments(java.lang.String... items);
  public A removeAllFromHeaderNameCaseAdjustments(Collection<String> items);
  public List<String> getHeaderNameCaseAdjustments();
  public String getHeaderNameCaseAdjustment(int index);
  public String getFirstHeaderNameCaseAdjustment();
  public String getLastHeaderNameCaseAdjustment();
  public String getMatchingHeaderNameCaseAdjustment(Predicate<String> predicate);
  public Boolean hasMatchingHeaderNameCaseAdjustment(Predicate<String> predicate);
  public A withHeaderNameCaseAdjustments(List<String> headerNameCaseAdjustments);
  public A withHeaderNameCaseAdjustments(java.lang.String... headerNameCaseAdjustments);
  public Boolean hasHeaderNameCaseAdjustments();
  
  /**
   * This method has been deprecated, please use method buildUniqueId instead.
   * @return The buildable object.
   */
  @Deprecated
  public IngressControllerHTTPUniqueIdHeaderPolicy getUniqueId();
  public IngressControllerHTTPUniqueIdHeaderPolicy buildUniqueId();
  public A withUniqueId(IngressControllerHTTPUniqueIdHeaderPolicy uniqueId);
  public Boolean hasUniqueId();
  public A withNewUniqueId(String format,String name);
  public IngressControllerHTTPHeadersFluent.UniqueIdNested<A> withNewUniqueId();
  public IngressControllerHTTPHeadersFluent.UniqueIdNested<A> withNewUniqueIdLike(IngressControllerHTTPUniqueIdHeaderPolicy item);
  public IngressControllerHTTPHeadersFluent.UniqueIdNested<A> editUniqueId();
  public IngressControllerHTTPHeadersFluent.UniqueIdNested<A> editOrNewUniqueId();
  public IngressControllerHTTPHeadersFluent.UniqueIdNested<A> editOrNewUniqueIdLike(IngressControllerHTTPUniqueIdHeaderPolicy item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface UniqueIdNested<N> extends Nested<N>,IngressControllerHTTPUniqueIdHeaderPolicyFluent<IngressControllerHTTPHeadersFluent.UniqueIdNested<N>>{
    public N and();
    public N endUniqueId();
    
  }
  
}
